"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createValidatorAsync = void 0;
const formatErrorMessage_1 = __importDefault(require("./formatErrorMessage"));
/**
 * Create a data asynchronous validator
 * @param data
 */
function createValidatorAsync(data, name) {
    function check(errorMessage) {
        return (checkResult) => {
            if (checkResult === false) {
                return { hasError: true, errorMessage };
            }
            else if (typeof checkResult === 'object' && (checkResult.hasError || checkResult.array)) {
                return checkResult;
            }
            return null;
        };
    }
    return (value, rules) => {
        const promises = rules.map(rule => {
            const { onValid, errorMessage, params } = rule;
            return Promise.resolve(onValid(value, data, name)).then(check((0, formatErrorMessage_1.default)(errorMessage, {
                ...params,
                name: Array.isArray(name) ? name.join('.') : name
            })));
        });
        return Promise.all(promises).then(results => results.find((item) => item && (item === null || item === void 0 ? void 0 : item.hasError)));
    };
}
exports.createValidatorAsync = createValidatorAsync;
exports.default = createValidatorAsync;
//# sourceMappingURL=createValidatorAsync.js.map